@@ -14,7 +14,7 @@
  saphana_sr_tools.py
  Author:       Fabian Herschel, May 2023
  License:      GNU General Public License (GPL)
- Copyright:    (c) 2023-2025 SUSE LLC
+ Copyright:    (c) 2023-2026 SUSE LLC
 
 # TODO: STEP01: SID-autodetection - get SID from query for SAPHanaController/SAPHanaTopologyResource - warn, if there are no or more than one SIDs found.
 # TODO: STEP02: Think also about multi SID implementation - maybe by using multiple HanaCluster objects (one per SID)
@@ -248,11 +248,12 @@ class HanaStatus():
         self.host_dict = None
         self.sids = None
 
-    def xml_import(self, filename):
+    def xml_import(self, filename, **kargs):
         """
         xml_import - import a cluster CIB into object dictionaries
             if filename is None, import the "life" cluster
         """
+        verbose = kargs.get('verbose', False)
         if filename is None:
             # use cibadmin as input
             cmd = "cibadmin -Ql"
@@ -271,7 +272,8 @@ class HanaStatus():
                 # bz2 ?
                 match_obj = re.search(r"\.bz2$", filename)
                 if match_obj:
-                    print(f"File {filename} ending with .bz2 is assumed to be compressed with bzip2 - try to uncompress")
+                    if verbose:
+                        print(f"File {filename} ending with .bz2 is assumed to be compressed with bzip2 - try to uncompress")
                     with bz2.open(filename, "rb") as f:
                         content = f.read()
                     self.root = ET.fromstring(content.decode())
